==> jc-1.4.0.tar.gz: javax/swing/text/NavigationFilter.h <==
// public class javax.swing.text.NavigationFilter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b294205b0bbbcca2 javax_swing_text_NavigationFilter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_NavigationFilter_H_
#define _JC_javax_swing_text_NavigationFilter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_NavigationFilter__24FilterBypass$object;
struct _jc_javax_swing_text_Position__24Bias$object;

// Typedefs
typedef struct _jc_javax_swing_text_NavigationFilter$sub_refs	_jc_javax_swing_text_NavigationFilter$sub_refs;
typedef struct _jc_javax_swing_text_NavigationFilter$sub_nonrefs	_jc_javax_swing_text_NavigationFilter$sub_nonrefs;
typedef struct _jc_javax_swing_text_NavigationFilter$refs	_jc_javax_swing_text_NavigationFilter$refs;
typedef struct _jc_javax_swing_text_NavigationFilter$nonrefs	_jc_javax_swing_text_NavigationFilter$nonrefs;
typedef struct _jc_javax_swing_text_NavigationFilter$object	_jc_javax_swing_text_NavigationFilter$object;

typedef const struct _jc_javax_swing_text_NavigationFilter$vmethods	_jc_javax_swing_text_NavigationFilter$vmethods;
typedef const struct _jc_javax_swing_text_NavigationFilter$vtable	_jc_javax_swing_text_NavigationFilter$vtable;
typedef const struct _jc_javax_swing_text_NavigationFilter$vtype	_jc_javax_swing_text_NavigationFilter$vtype;

// Constructors
extern void _jc_javax_swing_text_NavigationFilter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_NavigationFilter$object *);

// Virtual methods
extern void _jc_javax_swing_text_NavigationFilter$method$moveDot$f6fd5576ceb05e7e(_jc_env *, struct _jc_javax_swing_text_NavigationFilter$object *, struct _jc_javax_swing_text_NavigationFilter__24FilterBypass$object *, jint, struct _jc_javax_swing_text_Position__24Bias$object *);
extern void _jc_javax_swing_text_NavigationFilter$method$setDot$0d8aefc95f9a827b(_jc_env *, struct _jc_javax_swing_text_NavigationFilter$object *, struct _jc_javax_swing_text_NavigationFilter__24FilterBypass$object *, jint, struct _jc_javax_swing_text_Position__24Bias$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_NavigationFilter$method_info$moveDot$f6fd5576ceb05e7e;
extern _jc_method _jc_javax_swing_text_NavigationFilter$method_info$setDot$0d8aefc95f9a827b;

// Virtual methods structure
struct _jc_javax_swing_text_NavigationFilter$vmethods {
	void	(*moveDot$f6fd5576ceb05e7e)(_jc_env *, struct _jc_javax_swing_text_NavigationFilter$object *, struct _jc_javax_swing_text_NavigationFilter__24FilterBypass$object *, jint, struct _jc_javax_swing_text_Position__24Bias$object *);
	void	(*setDot$0d8aefc95f9a827b)(_jc_env *, struct _jc_javax_swing_text_NavigationFilter$object *, struct _jc_javax_swing_text_NavigationFilter__24FilterBypass$object *, jint, struct _jc_javax_swing_text_Position__24Bias$object *);
};

// Vtable
struct _jc_javax_swing_text_NavigationFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_NavigationFilter$vmethods	javax_swing_text_NavigationFilter;
};

// Vtype
struct _jc_javax_swing_text_NavigationFilter$vtype {
	_jc_type			type;
	_jc_javax_swing_text_NavigationFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_NavigationFilter$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_NavigationFilter$refs {
    _jc_javax_swing_text_NavigationFilter$sub_refs	javax_swing_text_NavigationFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_NavigationFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_NavigationFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_NavigationFilter$sub_nonrefs	javax_swing_text_NavigationFilter;
};

// Object instance structure
struct _jc_javax_swing_text_NavigationFilter$object {
	_jc_javax_swing_text_NavigationFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_NavigationFilter$vtype	*vtype;
	_jc_javax_swing_text_NavigationFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_NavigationFilter$vtype _jc_javax_swing_text_NavigationFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_NavigationFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_NavigationFilter$class_object;

#endif	/* _JC_javax_swing_text_NavigationFilter_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/NavigationFilter.h <==
// public class javax.swing.text.NavigationFilter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b294205b0bbbcca2 javax_swing_text_NavigationFilter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_NavigationFilter_H_
#define _JC_javax_swing_text_NavigationFilter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_NavigationFilter__24FilterBypass$object;
struct _jc_javax_swing_text_Position__24Bias$object;

// Typedefs
typedef struct _jc_javax_swing_text_NavigationFilter$sub_refs	_jc_javax_swing_text_NavigationFilter$sub_refs;
typedef struct _jc_javax_swing_text_NavigationFilter$sub_nonrefs	_jc_javax_swing_text_NavigationFilter$sub_nonrefs;
typedef struct _jc_javax_swing_text_NavigationFilter$refs	_jc_javax_swing_text_NavigationFilter$refs;
typedef struct _jc_javax_swing_text_NavigationFilter$nonrefs	_jc_javax_swing_text_NavigationFilter$nonrefs;
typedef struct _jc_javax_swing_text_NavigationFilter$object	_jc_javax_swing_text_NavigationFilter$object;

typedef const struct _jc_javax_swing_text_NavigationFilter$vmethods	_jc_javax_swing_text_NavigationFilter$vmethods;
typedef const struct _jc_javax_swing_text_NavigationFilter$vtable	_jc_javax_swing_text_NavigationFilter$vtable;
typedef const struct _jc_javax_swing_text_NavigationFilter$vtype	_jc_javax_swing_text_NavigationFilter$vtype;

// Constructors
extern void _jc_javax_swing_text_NavigationFilter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_NavigationFilter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_text_NavigationFilter$method$moveDot$f6fd5576ceb05e7e(_jc_env *, struct _jc_javax_swing_text_NavigationFilter$object *, struct _jc_javax_swing_text_NavigationFilter__24FilterBypass$object *, jint, struct _jc_javax_swing_text_Position__24Bias$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_NavigationFilter$method$setDot$0d8aefc95f9a827b(_jc_env *, struct _jc_javax_swing_text_NavigationFilter$object *, struct _jc_javax_swing_text_NavigationFilter__24FilterBypass$object *, jint, struct _jc_javax_swing_text_Position__24Bias$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_NavigationFilter$method_info$moveDot$f6fd5576ceb05e7e;
extern _jc_method _jc_javax_swing_text_NavigationFilter$method_info$setDot$0d8aefc95f9a827b;

// Virtual methods structure
struct _jc_javax_swing_text_NavigationFilter$vmethods {
	void	(*moveDot$f6fd5576ceb05e7e)(_jc_env *, struct _jc_javax_swing_text_NavigationFilter$object *, struct _jc_javax_swing_text_NavigationFilter__24FilterBypass$object *, jint, struct _jc_javax_swing_text_Position__24Bias$object *) _JC_JCNI_ATTR;
	void	(*setDot$0d8aefc95f9a827b)(_jc_env *, struct _jc_javax_swing_text_NavigationFilter$object *, struct _jc_javax_swing_text_NavigationFilter__24FilterBypass$object *, jint, struct _jc_javax_swing_text_Position__24Bias$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_NavigationFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_NavigationFilter$vmethods	javax_swing_text_NavigationFilter;
};

// Vtype
struct _jc_javax_swing_text_NavigationFilter$vtype {
	_jc_type			type;
	_jc_javax_swing_text_NavigationFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_NavigationFilter$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_NavigationFilter$refs {
    _jc_javax_swing_text_NavigationFilter$sub_refs	javax_swing_text_NavigationFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_NavigationFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_NavigationFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_NavigationFilter$sub_nonrefs	javax_swing_text_NavigationFilter;
};

// Object instance structure
struct _jc_javax_swing_text_NavigationFilter$object {
	_jc_javax_swing_text_NavigationFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_NavigationFilter$vtype	*vtype;
	_jc_javax_swing_text_NavigationFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_NavigationFilter$vtype _jc_javax_swing_text_NavigationFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_NavigationFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_NavigationFilter$class_object;

#endif	/* _JC_javax_swing_text_NavigationFilter_H_ */
